# spikely 
 An application built on top of SpikeInterface to create and run extracellular
data processing pipelines within a GUI. Spikely currently supports loading, preprocessing,
sorting, and curating extracellular datasets that are stored in SpikeInterface
compatible file formats.

To run Spikely, first you must install it:

```
pip install spikely
```

Once installed, spikely can be launched from the command line:

```
spikely
```

## Authors

[Roger Hurwitz](mailto:rogerhurwitz@gmail.com?subject=Spikely) - Software Developer, Portland, Oregon, USA

[Cole Hurwitz](https://www.inf.ed.ac.uk/people/students/Cole_Hurwitz.html) - The Institute for Adaptive and Neural Computation (ANC), University of Edinburgh, Edinburgh, Scotland 

![gui](./spikely/resources/spikely_gui.png)